@@ -1,5 +1,5 @@
 import sys
-import sflib
+from sf import sflib
 
 
 def main():
